# SPDX-FileCopyrightText: 2021 James Carr
#
# SPDX-License-Identifier: MIT


"""Constants"""


__version__ = "0.0.0-auto.0"
__repo__ = "https://github.com/adafruit/Adafruit_Blinka_Displayio.git"


DISPLAY_COMMAND = 0
DISPLAY_DATA = 1

CHIP_SELECT_UNTOUCHED = 0
CHIP_SELECT_TOGGLE_EVERY_BYTE = 1

BACKLIGHT_IN_OUT = 1
BACKLIGHT_PWM = 2
